<?php namespace Helper\MetadataGenerator;

    use Helper\MetadataGenerator\Metadata\General\General;
    use Helper\MetadataGenerator\Metadata\OpenGraph\OpenGraphMetadata;
    use Helper\MetadataGenerator\Metadata\OpenGraph\Article\Article;
    use Helper\MetadataGenerator\Metadata\Google\GooglePlusMetadata;
    use Helper\MetadataGenerator\Metadata\Twitter\TwitterMetadata;
    use Helper\MetadataGenerator\StructuredData\Article\ArticleJsonLD;
    use Helper\MetadataGenerator\StructuredData\Website\WebsiteJsonLD;
    use Helper\MetadataGenerator\StructuredData\Organization\OrganizationJsonLD;
    use Helper\MetadataGenerator\StructuredData\Breadcrumbs\BreadcrumbsJsonLD;
    use Helper\MetadataGenerator\StructuredData\LocalBusiness\LocalBusinessJsonLD;
    use Helper\MetadataGenerator\StructuredData\Event\EventJsonLD;
    use Helper\MetadataGenerator\StructuredData\Video\VideoJsonLD;
    use Helper\MetadataGenerator\StructuredData\Product\ProductJsonLD;

    class MetadataGenerator {

        /**
        * Get the general metadata for a page from an array of params
        *
        * @return string
        */
        public function getGeneralMetadata($data = array(),$format = false){
            
            $general = new General($format);
            $general->title = isset($data["title"]) ? $data["title"] : "";
            $general->description = isset($data["description"]) ? $data["description"] : "";
            $general->keywords = isset($data["keywords"]) ? $data["keywords"] : "";
            $general->author = isset($data["author"]) ? $data["author"] : "";
            $general->themeColor = isset($data["themeColor"]) ? $data["themeColor"] : "";
            $general->imageSrc = isset($data["imageSrc"]) ? $data["imageSrc"] : "";
            $general->icon = isset($data["icon"]) ? $data["icon"] : "";
            $general->charset = isset($data["charset"]) ? $data["charset"] : $general->charset;
            $general->canonical = isset($data["canonical"]) ? $data["canonical"] : "";
            $general->prev = isset($data["prev"]) ? $data["prev"] : "";
            $general->next = isset($data["next"]) ? $data["next"] : "";
            // <link rel="canonical" href="http://famatv.youoncontent.com"/>
            //

            return $general->toString();
        }

         /**
        * Get the general metadata for openGraph api from an array of params
        *
        * @return string
        */
        public function getOpenGraphMetadata($data = array(),$format = false){
            
            $openGraph = new OpenGraphMetadata($format);
            $openGraph->title = isset($data["title"]) ? $data["title"] : "";
            $openGraph->description = isset($data["description"]) ? $data["description"] : "";
            $openGraph->imageSrc = isset($data["imageSrc"]) ? $data["imageSrc"] : "";
            $openGraph->link = isset($data["canonical"]) ? $data["canonical"] : "";
            $openGraph->admins = isset($data["fbAdmins"]) ? $data["fbAdmins"] : "";
            $openGraph->app_id = isset($data["fbPageId"]) ? $data["fbPageId"] : "";
            $openGraph->type = isset($data["type"]) ? $data["type"] : "";
            $openGraph->ogImage = isset($data["imageObj"]) ? $data["imageObj"] : null;
            $openGraph->ogVideo = isset($data["videoObj"]) ? $data["videoObj"] : null;
            $openGraph->ogAudio = isset($data["audioObj"]) ? $data["audioObj"] : null;
            $openGraph->locale = isset($data["locale"]) ? $data["locale"] : "";
            $openGraph->l10n = isset($data["l10n"]) ? $data["l10n"] : array();
            $openGraph->siteName = isset($data["siteName"]) ? $data["siteName"] : "";
            
            $print = $openGraph->toString();

            if(strtolower($openGraph->type) == "article" && isset($data["article"])){
                $article = new Article($format);
                $article->authors = isset($data["article"]["authors"]) ? $data["article"]["authors"] : array();
                $article->publisher = isset($data["article"]["publisher"]) ? $data["article"]["publisher"] : "";
                $article->pubDate = isset($data["article"]["pubDate"]) ? $data["article"]["pubDate"] : "";
                $article->modDate = isset($data["article"]["modDate"]) ? $data["article"]["modDate"] : "";
                $article->dossier = isset($data["article"]["dossier"]) ? $data["article"]["dossier"] : "";
                $article->tags = isset($data["article"]["tags"]) ? $data["article"]["tags"] : array();
                
                
                $print .= "\n".$article->toString();
            }

            return $print;
        }
         /**
        * Get the general metadata for google plus from an array of params
        *
        * @return string
        */
        public function getGooglePlusMetadata($data = array(),$format = false){
            $gplus = new GooglePlusMetadata($format);
            $gplus->title = isset($data["title"]) ? $data["title"] : "";
            $gplus->description = isset($data["description"]) ? $data["description"] : "";
            $gplus->imageSrc = isset($data["imageSrc"]) ? $data["imageSrc"] : "";
            

            return $gplus->toString();
        }
         /**
        * Get the general metadata for twitter from an array of params
        *
        * @return string
        */
        public function getTwitterMetadata($data = array(),$format = false){
           $tw = new TwitterMetadata($format);
           $tw->card = isset($data["twCard"]) ? $data["twCard"] : "summary_large_image";
           $tw->site = isset($data["twSite"]) ? $data["twSite"] : "";
           $tw->title = isset($data["title"]) ? $data["title"] : "";
           $tw->description = isset($data["description"]) ? $data["description"] : "";
           $tw->creator = isset($data["twCreator"]) ? $data["twCreator"] : "";
           $tw->imageSrc = isset($data["imageSrc"]) ? $data["imageSrc"] : "";
           $tw->twImage = isset($data["imageObj"]) ? $data["imageObj"] : null;
           $tw->twVideo = isset($data["videoObj"]) ? $data["videoObj"] : null;
          

           return $tw->toString();

        }

         /**
        * Get the structured data (json+ld)
        *
        * @return string
        */
        public function getStructuredData($data = array(),$format = false){
            //"<script type=\"application/ld+json\">" array() </script>
            $jsons = array();
            if(isset($data["website"])){
                $website = new WebsiteJsonLD($format);
                $website->url = isset($data["website"]["url"]) ? $data["website"]["url"] : "";
                $website->social = isset($data["website"]["social"]) ? $data["website"]["social"] : array();
                $website->search = isset($data["website"]["search"]) ? $data["website"]["search"] : false;
                $website->searchLink = isset($data["website"]["searchLink"]) ? $data["website"]["searchLink"] : "";
                $website->searchQueryName = isset($data["website"]["searchQueryName"]) ? $data["website"]["searchQueryName"] : "q";
                $website->siteName = isset($data["website"]["name"]) ? $data["website"]["name"] : "";
                $website->image = isset($data["imageSrc"]) ? $data["imageSrc"] : "";

                array_push( $jsons, $website->toString() );

            }

            if(isset($data["organization"])){
                $organization = new OrganizationJsonLD($format);
                $organization->url = isset($data["organization"]["url"]) ? $data["organization"]["url"] : "";
                $organization->social = isset($data["organization"]["social"]) ? $data["organization"]["social"] : array();
                $organization->logo = isset($data["organization"]["logo"]) ? $data["organization"]["logo"] : "";
                $organization->companyName = isset($data["organization"]["name"]) ? $data["organization"]["name"] : "";
                $organization->contacts = isset($data["organization"]["contacts"]) ? $data["organization"]["contacts"] : array();
                
                
                array_push( $jsons, $organization->toString() );

            }

            if(isset($data["breadcrumbs"])){
                $breadcrumbs = new BreadcrumbsJsonLD($format);
                $breadcrumbs->items = $data["breadcrumbs"];
            
                array_push( $jsons, $breadcrumbs->toString() );
            }
            
            if(isset($data["localbusiness"])){
                
                $business = new LocalBusinessJsonLD($data["localbusiness"]["type"],$format);
                $business->url = isset($data["localbusiness"]["url"]) ? $data["localbusiness"]["url"] : "";
                $business->name = isset($data["localbusiness"]["name"]) ? $data["localbusiness"]["name"] : "";
                $business->description = isset($data["localbusiness"]["description"]) ? $data["localbusiness"]["description"] : "";
                $business->image = isset($data["localbusiness"]["image"]) ? $data["localbusiness"]["image"] : array();
                $business->phone = isset($data["localbusiness"]["phone"]) ? $data["localbusiness"]["phone"] : "";
                $business->email = isset($data["localbusiness"]["email"]) ? $data["localbusiness"]["email"] : "";
                $business->address = isset($data["localbusiness"]["address"]) ? $data["localbusiness"]["address"] : array();
                $business->geo  = isset($data["localbusiness"]["geo"]) ? $data["localbusiness"]["geo"] : array();
                $business->schedule = isset($data["localbusiness"]["schedule"]) ? $data["localbusiness"]["schedule"] : array();
                $business->menuUrl = isset($data["localbusiness"]["menu"]) ? $data["localbusiness"]["menu"] : "";
                $business->acceptsReservations = isset($data["localbusiness"]["reservations"]) ? $data["localbusiness"]["reservations"] : false;
                $business->servesCuisine = isset($data["localbusiness"]["cuisine"]) ? $data["localbusiness"]["cuisine"] : "";
                $business->social = isset($data["localbusiness"]["social"]) ? $data["localbusiness"]["social"] : array();
                $business->priceRange = isset($data["localbusiness"]["priceRange"]) ? $data["localbusiness"]["priceRange"] : "";
                $business->map = isset($data["localbusiness"]["map"]) ? $data["localbusiness"]["map"] : "";
                $business->departments = isset($data["localbusiness"]["departments"]) ? $data["localbusiness"]["departments"] : array();
            
                array_push( $jsons, $business->toString() ); 
            }

            
            if(isset($data["events"])){
                foreach($data["events"] as $eventData){
                    
                    $event = new EventJsonLD($format);
                    $event->eventName =  isset($eventData["eventName"]) ? $eventData["eventName"] : "";
                    $event->startDate = isset($eventData["startDate"]) ? $eventData["startDate"] : "";
                    $event->address = isset($eventData["address"]) ? $eventData["address"] : array();
                    $event->placeName = isset($eventData["placeName"]) ? $eventData["placeName"] : "";
                    $event->image =  isset($eventData["image"]) ? $eventData["image"] : array();
                    $event->description =  isset($eventData["description"]) ? $eventData["description"] : "";
                    $event->endDate =  isset($eventData["endDate"]) ? $eventData["endDate"] : "";
                    $event->performer =  isset($eventData["performer"]) ? $eventData["performer"] : "";
                    $event->offers =  isset($eventData["offers"]) ? $eventData["offers"] : array();
                    $event->performerIsGroup = isset($eventData["performerIsGroup"]) ? $eventData["performerIsGroup"] : false;

                    array_push( $jsons, $event->toString() ); 
                }
            }

            
            $type = isset($data["type"]) ? $data["type"] : "";
            if($type == "article" && isset($data["article"])){

                $article = new ArticleJsonLD($format);
                $article->title = isset($data["title"]) ? $data["title"] : "";
                $article->description = isset($data["description"]) ? $data["description"] : "";
                $article->ent_id = isset($data["canonical"]) ? $data["canonical"] : "";
                $article->image = isset($data["imageSrc"]) ? $data["imageSrc"] : "";
                $article->pubDate = isset($data["article"]["pubDate"]) ? $data["article"]["pubDate"] : "";
                $article->modDate = isset($data["article"]["modDate"]) ? $data["article"]["modDate"] : ""; 
                $article->publisher = isset($data["siteName"]) ? $data["siteName"] : "";
                $article->favicon = isset($data["icon"]) ? $data["icon"] : "";
                $article->authors = isset($data["article"]["authors"]) ? $data["article"]["authors"] : array();
                array_push( $jsons, $article->toString() );
            }  

            if($type == "video" && isset($data["videoObj"])){
                $video = new VideoJsonLD($format);
                $video->name = isset($data["videoObj"]["name"])  ?$data["videoObj"]["name"]  : $data["title"];
                $video->description = isset($data["videoObj"]["description"])  ?$data["videoObj"]["description"]  : $data["description"];
                $video->embedUrl = isset($data["videoObj"]["url"])  ?$data["videoObj"]["url"]  : "";
                $video->contentUrl = isset($data["videoObj"]["contentUrl"])  ?$data["videoObj"]["contentUrl"]  : "";
                $video->image = isset($data["videoObj"]["thumbnail"])  ?$data["videoObj"]["thumbnail"]  : array();
                $video->duration = isset($data["videoObj"]["duration"])  ?$data["videoObj"]["duration"]  : "0";
                $video->views = isset($data["videoObj"]["views"])  ?$data["videoObj"]["views"]  : "";
                $video->uploadDate = isset($data["videoObj"]["uploadDate"])  ?$data["videoObj"]["uploadDate"]  : "";

                array_push( $jsons, $video->toString() );
            }
            if($type == "product" && isset($data["product"])){
                $product = new ProductJsonLD($format);
                $product->name = isset($data["product"]["name"]) ? $data["product"]["name"]  : "";
                $product->image = isset($data["product"]["image"]) ? $data["product"]["image"]  : array();
                $product->description = isset($data["product"]["description"]) ? $data["product"]["description"]  : "";
                $product->brandName = isset($data["product"]["brandName"]) ? $data["product"]["brandName"]  : "";
                $product->offers = isset($data["product"]["offers"]) ? $data["product"]["offers"] : array();
                $product->sku  = isset($data["product"]["sku"]) ? $data["product"]["sku"]  : "";

                array_push( $jsons, $product->toString() );
            }

            
            if(count($jsons) > 0) {

                $str = "<script type=\"application/ld+json\"> [";

                for($i = 0 ; $i < count($jsons) ; $i++){
                    $str .= ($i > 0 ? "," : "").$jsons[$i];
                }

                return $str."]</script>";
            }else{
                return "";
            }
        }

         /**
        * Get everything
        *
        * @return string
        */
        public function getAllMetadata($data = array(),$format = false){

            return  $this->getGeneralMetadata($data,$format).
                    $this->getOpenGraphMetadata($data,$format).
                    $this->getGooglePlusMetadata($data,$format).
                    $this->getTwitterMetadata($data,$format).
                    $this->getStructuredData($data,$format);

        }
    }

?>