<?php namespace Helper\MetadataGenerator\StructuredData\Event;

use Helper\MetadataGenerator\StructuredData\JsonLDGenerator;
use Helper\MetadataGenerator\StructuredData\StockManagement;

class EventJsonLD extends JsonLDGenerator{

    public $eventName = "";

    public $startDate = "";

    public $address = array();

    public $placeName  ="";
    
    public $image = array();
    
    public $description = "";

    public $endDate = "";

    public $performer = "";
    public $performerIsGroup = false;

    public $offers = array();
   
    public $formated = 0;

    

    public function __construct($format = false){
      parent::__construct();
      $this->type = "Event";
      $this->formated = $format ? 128 : 0;
    }

    private function printLocation(){
        $data = array();
        if($this->placeName != "" && count($this->address) > 0){
            $data["@type"] = "Place";
            $data["name"] = $this->placeName;
            $data["address"] = array();
            $data["address"]["streetAddress"] = isset($this->address["streetAddress"]) ? $this->address["streetAddress"] : "";
            $data["address"]["addressLocality"] = isset($this->address["city"]) ? $this->address["city"] : "";
            $data["address"]["addressRegion"] = isset($this->address["region"]) ? $this->address["region"] : "";
            $data["address"]["postalCode"] = isset($this->address["zipcode"]) ? $this->address["zipcode"] : "";
            $data["address"]["addressCountry"] = isset($this->address["country"]) ? $this->address["country"] : "";
        }

        return $data;
    }

    private function printOffers(){
        $data = array();
        if(isset($this->offers) && count($this->offers) > 0){
           foreach($this->offers as $offer){
               $off = array();
               $off["@type"] =  "Offer";
               $off["url"] =  isset($offer["url"]) ? $offer["url"]  : "";
               $off["price"] =  isset($offer["price"]) ? $offer["price"]  : "";
               $off["priceCurrency"] =  isset($offer["currency"]) ? $offer["currency"] : "";
               $off["availability"] =  isset($offer["availability"]) && StockManagement::isValidValue($offer["availability"],true) ? $offer["availability"] : StockManagement::InStock;
               $off["validFrom"] =  isset($offer["startDate"]) ? $offer["startDate"] : "" ;
               $off["validThrough"] = isset($offer["endDate"]) ? $offer["endDate"] : "" ;

               array_push($data,$off);
           }
        }

        return $data;
    }
  
    public function toString(){
        $data = array();
        $data["@context"] = $this->context;
        $data["@type"]  = $this->type;
        $data["name"] = $this->eventName;
        $data["startDate"] = $this->startDate;
        $data["endDate"] = $this->endDate;

        $location = $this->printLocation();
        if(count($location) > 0)
            $data["location"] = $location;

        if(count($this->image) > 0)
            $data["image"] = $this->image;
        
        $data["description"] = htmlentities($this->description,ENT_QUOTES,"UTF-8");

        $offers = $this->printOffers();
        if(count($offers) > 0)
            $data["offers"] = $offers;
        
        if($this->performer != ""){
            $data["performer"] = array(
                "@type" => $this->performerIsGroup ? "PerformingGroup" : "Person",
                "name" => $this->performer
            );
        }
        
        return json_encode($data,$this->formated);
    }
}