<?php namespace Helper\MetadataGenerator\StructuredData\LocalBusiness;

use Helper\MetadataGenerator\StructuredData\JsonLDGenerator;


class LocalBusinessJsonLD extends JsonLDGenerator{

    public $url = "";
    public $name = "";
    public $description = "";
    public $image  = array();
    public $phone = "";
    public $email = "";
    public $address = array();
    public $geo = array();
    public $schedule = array();
    public $social = array();
    

    public $priceRange = "";
    public $menuUrl = "";
    public $acceptsReservations = false;
    public $servesCuisine = "";


    public $map = "";
    public $departments = array();


    public $formated = 0;

    public function __construct($type,$format = false){
      parent::__construct();
      $this->type = $type;
      $this->formated = $format ? 128 : 0;
    }

    private function printGeo(){
        $data = array();

       if(isset($this->geo) && count($this->geo) > 0){
           $data["@type"] = "GeoCoordinates";
           $data["latitude"] = isset($this->geo["latitude"]) ? $this->geo["latitude"] : "";
           $data["longitude"] = isset($this->geo["longitude"]) ? $this->geo["longitude"] : "";
       }

       return $data;
    }

    private function printAddress(){
        $data = array();

        if(isset($this->address) && count($this->address) > 0){
            $data["@type"] = "PostalAddress";
            $data["streetAddress"] = isset($this->address["streetAddress"]) ? $this->address["streetAddress"] : "";
            $data["addressLocality"] = isset($this->address["city"]) ? $this->address["city"] : "";
            $data["addressRegion"] = isset($this->address["region"]) ? $this->address["region"] : "";
            $data["postalCode"] = isset($this->address["zipcode"]) ? $this->address["zipcode"] : "";
            $data["addressCountry"] = isset($this->address["country"]) ? $this->address["country"] : "";

        }

        return $data;
    }

    private function printSchedule(){
        $data = array();

        if(isset($this->schedule) && count($this->schedule) > 0){
            foreach($this->schedule as $day){
                $found = false;
                if( isset($day["opens"]) && isset($day["closes"])){
                    for($i = 0; $i < count($data); $i++ ){
                        $cell = $data[$i];
                        if($cell["opens"] == $day["opens"] && $cell["closes"] == $day["closes"]){
                            
                            array_push($cell["dayOfWeek"],$day["dayOfWeek"]);

                            $data[$i] = $cell;
                            $found = true;
                            
                            break;
                        }
                    }
                    
                    if($found == false){
                        array_push($data,array(
                            "@type" => "OpeningHoursSpecification",
                            "dayOfWeek" => array($day["dayOfWeek"]),
                            "opens" => $day["opens"],
                            "closes" => $day["closes"]
                        ));
                    }
                }
            }
            
        }

        return $data;

    }

    public function toString($asArray = false){
        $data = array();
        $data["@context"] = $this->context;
        $data["@type"]  = $this->type;
        if($this->url != ""){
            $data["@id"] = $this->url;
            $data["url"] = $this->url;
        }
        if($this->description != "")
            $data["description"] = $this->description;

        $data["name"] = $this->name;

        if(isset($this->image) && count($this->image) > 0)
            $data["image"] = $this->image;
        
        if(isset($this->social) && count($this->social) > 0)
            $data["sameAs"] = $this->social;
        
        $data["telephone"] = $this->phone;
        $data["email"] = $this->email;

        $geo = $this->printGeo();
        if(count($geo) > 0){
            $data["geo"] = $geo;
        }

        $address = $this->printAddress();
        if(count($address) > 0){
            $data["address"] = $address;
        }
    
        $schedule = $this->printSchedule();
        if(count($schedule) > 0){
            $data["openingHoursSpecification"] = $schedule;
        }
        
        if($this->priceRange != "")
            $data["priceRange"] = $this->priceRange;

        if($this->servesCuisine != "")    
            $data["servesCuisine"] = $this->servesCuisine;

        if($this->map != "")    
            $data["hasMap"] = $this->map;    

        if(isset($this->departments) && count($this->departments) > 0){
            $data["department"] = array();
            foreach($this->departments as $department){
                $type = isset($department["type"]) ? $department["type"] : $this->type;
                $dep = new LocalBusinessJsonLD($type , $this->formated);
                $dep->url = isset($department["url"]) ? $department["url"] : "";
                $dep->name = isset($department["name"]) ? $department["name"] : "";
                $dep->description = isset($department["description"]) ? $department["description"] : "";
                $dep->image = isset($department["image"]) ? $department["image"] : $this->image;
                $dep->phone = isset($department["phone"]) ? $department["phone"] : "";
                $dep->email = isset($department["email"]) ? $department["email"] : "";
                $dep->address = isset($department["address"]) ? $department["address"] : array();
                $dep->geo  = isset($department["geo"]) ? $department["geo"] : array();
                $dep->schedule = isset($department["schedule"]) ? $department["schedule"] : array();
                $dep->menuUrl = isset($department["menu"]) ? $department["menu"] : "";
                $dep->acceptsReservations = isset($department["reservations"]) ? $department["reservations"] : false;
                $dep->servesCuisine = isset($department["cuisine"]) ? $department["cuisine"] : $this->servesCuisine;
                $dep->social = isset($department["social"]) ? $department["social"] : array();
                $dep->priceRange = isset($department["priceRange"]) ? $department["priceRange"] : $this->priceRange;
                $dep->map = isset($department["map"]) ? $department["map"] : "";

                array_push($data["department"],$dep->toString(true));
            }
        }

              
        if($asArray){
            return $data;
        }

        return json_encode($data,$this->formated);
    }
}