<?php namespace Helper\MetadataGenerator\StructuredData\Product;

use Helper\MetadataGenerator\StructuredData\JsonLDGenerator;
use Helper\MetadataGenerator\StructuredData\StockManagement;
use Helper\MetadataGenerator\StructuredData\ItemConditionType;

class ProductJsonLD extends JsonLDGenerator{

    public $name = "";

    public $image = array();
    
    public $description = "";

    public $brandName = "";

    public $offers = array();
   
    public $formated = 0;

    public $sku = "";
    

    public function __construct($format = false){
      parent::__construct();
      $this->type = "Product";
      $this->formated = $format ? 128 : 0;
    }

    

    private function printOffers(){
        $data = array();
        if(isset($this->offers) && count($this->offers) > 0){
           foreach($this->offers as $offer){
               $off = array();
               $off["@type"] =  "Offer";
               $off["url"] =  isset($offer["url"]) ? $offer["url"]  : "";
               $off["price"] =  isset($offer["price"]) ? $offer["price"]  : "";
               $off["priceCurrency"] =  isset($offer["currency"]) ? $offer["currency"] : "";
               $off["availability"] =  isset($offer["availability"]) && StockManagement::isValidValue($offer["availability"],true) ? $offer["availability"] : StockManagement::InStock;
               $off["itemCondition"] = isset($offer["condition"]) && ItemConditionType::isValidValue($offer["condition"],true) ? $offer["condition"] : ItemConditionType::NewCondition;
               $off["priceValidUntil"] = isset($offer["endDate"]) ? $offer["endDate"] : "" ;
               if(isset($offer["sellerName"]))
                    $off["seller"] = array("@type" => "Organization" , "name" => $offer["sellerName"]);

               array_push($data,$off);
           }
        }

        return $data;
    }
  
    public function toString(){
        $data = array();
        $data["@context"] = $this->context;
        $data["@type"]  = $this->type;
        $data["name"] = $this->name;
    
        if(count($this->image) > 0)
            $data["image"] = $this->image;
        
        $data["description"] = htmlentities($this->description,ENT_QUOTES,"UTF-8");

        $offers = $this->printOffers();
        if(count($offers) > 0)
            $data["offers"] = $offers;
        
        if($this->sku != ""){
            $data["sku"] = $this->sku;
        }

        if($this->brandName != ""){
            $data["brand"] = array("@type" => "Thing", "name" => $this->brandName );
        }
        
        return json_encode($data,$this->formated);
    }
}